@@ -1,5 +1,5 @@
-tdrankadjperc <- function( td, percentiles = c( 0.5, 1, 2, 5, 95 ),
-                           type = c( "quantile", "(i-1)/(n-1)", "i/(n+1)", "i/n" ) ) {
+tdrankadjperc <- function( td, percentiles = c( 0.5, 1, 2, 5, 95 ), type = "conventional",
+                           typequantiles = c( "quantile", "(i-1)/(n-1)", "i/(n+1)", "i/n" ) ) {
 # gets percentiles for TD rank curve. TDs should come from control subjects from a
 # set of visual fields it fits lines to characterize age effect on the visual-field
 # sensitivities. For this function all visual fields should correspond to the
@@ -14,6 +14,8 @@ tdrankadjperc <- function( td, percentiles = c( 0.5, 1, 2, 5, 95 ),
     stop("mixing different patterns of locations")
   }
 
+  if( type != "conventional" & type != "ghrank" ) stop( "wrong type of global sensitivity estimation" )
+
 # get settings for the pattern of test locations
   locini   <- vfsettings$locini
   texteval <- paste( "vfsettings$", td$tpattern[1], sep = "" )
@@ -49,20 +51,37 @@ tdrankadjperc <- function( td, percentiles = c( 0.5, 1, 2, 5, 95 ),
   }
   tdrper  <- as.data.frame( tdrper )
 # remove the locations corresponding to blind spots (which are not to be analyzed)
-  lenbs <- 0
-  if( all( !is.na( settings$bs ) ) ) lenbs <- length( settings$bs )
-  tdrper   <- tdrper[1:( nrow( tdrper ) - lenbs ),]
+  tdrper   <- tdrper[1:( nrow( tdrper ) - length( settings$bs ) ),]
   tdr <- tdrank( td )
-# adjusted curves to the "85th percentile"
-  tdr[,locini:ncol( tdr )] <- tdr[,locini:ncol( tdr )] - tdr[,locini+settings$locrPD-1]
+
+# get the mean normal TD-rank curve
+  tdrnv  <- tdranknv( td )$mtdr
+  tdrnv2 <- td[1,]
+  tdrnv2[,locini:ncol( tdr )] <- tdrnv
+# adjusted curves using GH or global-sensitivity estimates
+  gh <- NULL
+  if( type == "conventional" ){
+    for( i in 1:nrow( tdr) ) {
+      gh[i] <- -ghpostd( td[i,] )
+    }
+    ghnv <- -ghpostd( tdrnv2 )
+  }
+  if( type == "ghrank" ){
+    for( i in 1:nrow( tdr) ) {
+      gh[i] <- ghranktd( td[i,] )$gh
+    }
+    ghnv <- ghranktd( tdrnv2 )$gh
+  }
+  for( i in 1:nrow( tdr) ) {
+    tdr[i,locini:ncol( tdr )] <- tdr[i,locini:ncol( tdr )] + gh[i]
+  }    
   k <- 0
   for( i in locini:ncol( tdr ) ) {
     k <- k + 1
-    tdrper[k,] <- wtd.quantile( tdr[,i], probs = percentiles / 100, type = type, weights = idweight,
+    tdrper[k,] <- wtd.quantile( tdr[,i], probs = percentiles / 100, type = typequantiles, weights = idweight,
                                    normwt = TRUE )
   }
-  tdrnv <- as.numeric( tdranknv( td )$mtdr )
-  for( i in 1:ncol( tdrper ) ) tdrper[,i] <- tdrper[,i] - ( tdrnv - tdrnv[settings$locrPD] )
+  for( i in 1:ncol( tdrper ) ) tdrper[,i] <- tdrper[,i] - ( tdrnv + ghnv )
 
   return( tdrper )
 }
