@@ -4,7 +4,7 @@ vfplot <- function( vf, plotType, notSeenAsBlack = TRUE, newWindow = FALSE,
                     outerSymbol = "circles", innerSymbol = "circles",
                     outerSize = 1, innerSize = 1,
                     outerInch = 0.14, innerInch = 0.08,
-                    lengthLines = 0, thicknessLines = 0 ) {
+                    lengthLines = 4.25, thicknessLines = 2 ) {
 
 # check that vf has only 1 entry
   if( nrow( vf ) > 1 ) {
@@ -13,7 +13,7 @@ vfplot <- function( vf, plotType, notSeenAsBlack = TRUE, newWindow = FALSE,
 
 # Check that symbol input arguments are consistent
 # sizes must be arrays, not matrices
-  if( is.matrix(outerSize ) ) {
+  if( is.matrix( outerSize ) ) {
     stop( "Error! outerSize cannot be a matrix" )
   }
   if( is.matrix( innerSize ) ) {
@@ -86,6 +86,14 @@ vfplot <- function( vf, plotType, notSeenAsBlack = TRUE, newWindow = FALSE,
     devP <- pdpmap( dev )
   }
 
+# if plot type id "pdghr" then first calculate total deviation
+# use the total deviation to calculate pattern deviation from global-sensitivity estimate
+  if( plotType == "pdghr" ) {
+    dev  <- tdval( vf )
+    dev  <- pdvalghr( dev )
+    devP <- pdpmapghr( dev )
+  }
+
 # getRGB will return a table with the red, green and blue intensity values 
 # corresponding to pattern deviation at each location
   if( plotType == "vf" ) {
@@ -107,6 +115,9 @@ vfplot <- function( vf, plotType, notSeenAsBlack = TRUE, newWindow = FALSE,
     if( all( !is.na( bspos ) ) ) plotColor  <- plotColor[-bspos,]
   }
 
+  # if NA then plot all in black
+  plotColor[is.na( plotColor )] <- 0
+
 # create a new window and plot data in it
 # window rescale is set to fixed to ensure re-sizing window doesn't re-size the plot
   height <- width * yminmax / xminmax
@@ -116,20 +127,16 @@ vfplot <- function( vf, plotType, notSeenAsBlack = TRUE, newWindow = FALSE,
       if( Sys.info()["sysname"] == "Darwin" ) {
         options( device = "quartz" )
         dev.new( width = width, height = height, dpi = 85 )
-        #        quartz( width = width, height = height, dpi = 85 )
       } else {
         options( device = "x11" )
         dev.new( width = width, height = height )
-        #        x11( xpos = 0, ypos = 0, width = width, height = height )
       }
     } else{
       options( device = "windows" )
       dev.new( width = width, height = height, rescale = "fixed" )
-      #      windows( xpos = 0, ypos = 0, width = width, height = height, rescale = "fixed" )
     }
     options( device = device )
   }
-
   vfplotloc( cloneDev, eye = vf$seye, patternMap = patternMap, outerColor = plotColor,
              bs = c( vf$sbsx, vf$sbsy ),
              txtfont = txtfont, pointsize = pointsize,
